package fr.itsee.zelyx;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;

public class ProduitAdapterControle extends RecyclerView.Adapter<ProduitAdapterControle.MyViewHolder> {

    private List<Produit> listeProduit;
    private Context context;
    private ProduitAdapterControle.OnItemClickListener mListener;

    public ProduitAdapterControle(ArrayList<Produit> listeProduit, Context context) {
        this.listeProduit = listeProduit;
        this.context = context;
    }

    public void setListeProduit(List<Produit> listeProduit) {
        this.listeProduit = listeProduit;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit_controle, parent, false);

        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {

        final Produit p = listeProduit.get(position);

        holder.ref.setText(p.getRef());
        if (p.getNumero_de_rayon().isEmpty()) {
            holder.rayon.setText("Num rayon: inconnu");
        } else {
            holder.rayon.setText("Num rayon: " + p.getNumero_de_rayon());
        }
        holder.coloris.setText(p.getColoris());

        DecimalFormat df = new DecimalFormat("0.00");
        holder.qte.setText("Qté total: " + p.getQte());
        holder.prixTotale.setText("" + df.format(p.getPrixTotale()));
        if (!p.getLien_image().equals("")) {
            String imageURL = MainActivity.backOfficeURLIMG + p.getLien_image();
            Picasso.with(this.context).load(imageURL).placeholder(R.drawable.image_not_found).error(R.drawable.image_not_found).into(holder.photo);
        } else {
            holder.photo.setImageResource(R.drawable.image_not_found);
        }

        holder.nbrScanner.setText(p.getNbrScanner() + "/" + p.getQte());

        if (listeProduit.get(position).getNbrScanner() == listeProduit.get(position).getQte()) {
            holder.itemView.setBackgroundColor(Color.GREEN);
        } else if (listeProduit.get(position).getNbrScanner() > listeProduit.get(position).getQte()) {
            holder.itemView.setBackgroundColor(Color.RED);
        } else {
            holder.itemView.setBackgroundColor(Color.TRANSPARENT);
        }

    }

    public void setOnItemClickListener(ProduitAdapterControle.OnItemClickListener listener) {
        mListener = listener;
    }

    @Override
    public int getItemCount() {
        return listeProduit.size();
    }

    public interface OnItemClickListener {
        void onPhotoClick(int position, Drawable imageDrawable, String lien_image);
    }

    public class MyViewHolder extends RecyclerView.ViewHolder {
        public TextView ref, rayon, stock, coloris, qte, prixTotale, nbrScanner;
        public ImageView photo;

        public MyViewHolder(View view, final ProduitAdapterControle.OnItemClickListener listener) {
            super(view);
            ref = view.findViewById(R.id.ref);
            rayon = view.findViewById(R.id.rayon);
            coloris = view.findViewById(R.id.coloris);
            qte = view.findViewById(R.id.qte);
            prixTotale = view.findViewById(R.id.prixTotale);
            photo = view.findViewById(R.id.photo);
            nbrScanner = view.findViewById(R.id.nbrScanner);

            photo.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            Drawable imageProduitDrawable = photo.getDrawable();
                            final Produit p = listeProduit.get(position);
                            listener.onPhotoClick(position, imageProduitDrawable, p.getLien_image());
                        }
                    }
                }
            });
        }
    }

}