package fr.itsee.zelyx;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;

public class ProduitAdapterRecherche extends RecyclerView.Adapter<ProduitAdapterRecherche.MyViewHolder> {

    private List<Produit> listeAllProduit;
    private OnItemClickListener mListener;
    private Context context;

    public ProduitAdapterRecherche(ArrayList<Produit> listeAllProduit, Context context) {
        this.listeAllProduit = listeAllProduit;
        this.context = context;
    }

    public void setOnItemClickListener(OnItemClickListener listener) {
        mListener = listener;
    }

    public void setListeAllProduit(List<Produit> listeAllProduit) {
        this.listeAllProduit = listeAllProduit;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit_recherche, parent, false);
        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        final Produit p = listeAllProduit.get(position);
        DecimalFormat df = new DecimalFormat("0.00");
        holder.ref.setText(p.getRef());
        if (p.getPrixPromo() > 0) {
            holder.prix.setText("P.U.: " + df.format(p.getPrix()) + " (Promo: " + df.format(p.getPrixPromo()) + ")");
            p.setPrix(p.getPrixPromo());
            p.setSiPromo(1);
        } else {
            holder.prix.setText("P.U.: " + df.format(p.getPrix()));
        }
        holder.prixTotal.setText("" + df.format(p.getPrixTotale()));
        holder.textStockTotal.setText("Stock total: " + p.getQteTotalRef());
        holder.textStockCouleur.setText("Stock \"" + p.getColoris() + "\": " + p.getStock());

        if (!p.getLien_image().equals("")) {
            String imageURL = MainActivity.backOfficeURLIMG + p.getLien_image();
            Picasso.with(this.context).load(imageURL).placeholder(R.drawable.image_not_found).error(R.drawable.image_not_found).into(holder.photo);
        } else {
            holder.photo.setImageResource(R.drawable.image_not_found);
        }
    }

    @Override
    public int getItemCount() {
        return listeAllProduit.size();
    }

    public interface OnItemClickListener {
        void onPhotoClick(int position, Drawable imageDrawable, String lien_image);
        void onClik(int position);

    }

    public class MyViewHolder extends RecyclerView.ViewHolder {
        public TextView ref, prix, prixTotal, textStockTotal, textStockCouleur;
        public ImageView photo;

        public MyViewHolder(View view, final OnItemClickListener listener) {
            super(view);
            ref = view.findViewById(R.id.ref);
            prix = view.findViewById(R.id.prix);
            prixTotal = view.findViewById(R.id.prixTotal);
            photo = view.findViewById(R.id.photo);
            textStockTotal = view.findViewById(R.id.textStockTotal);
            textStockCouleur = view.findViewById(R.id.textStockCouleur);

            view.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onClik(position);
                        }
                    }
                }
            });

            photo.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            Drawable imageProduitDrawable = photo.getDrawable();
                            final Produit p = listeAllProduit.get(position);
                            listener.onPhotoClick(position, imageProduitDrawable, p.getLien_image());
                        }
                    }
                }
            });
        }
    }

}