package fr.itsee.zelyx;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.provider.Settings;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.MotionEvent;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.ImageView;
import android.widget.SearchView;
import android.widget.Toast;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

public class RechercheActivity extends AppCompatActivity {

    private RecyclerView recyclerView;
    private ProduitAdapterRecherche mAdapter;
    private List<Produit> resultatRecherche;
    private SearchView searchBar;
    private String recherche;
    private ImageView image_produit_full;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_recherche);

        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }

        searchBar = findViewById(R.id.bar_de_recherche);
        recyclerView = findViewById(R.id.recycler_view);
        mAdapter = new ProduitAdapterRecherche(new ArrayList<Produit>(), this.getApplicationContext());

        RecyclerView.LayoutManager mLayoutManager = new LinearLayoutManager(getApplicationContext());
        recyclerView.setLayoutManager(mLayoutManager);
        recyclerView.setItemAnimator(new DefaultItemAnimator());
        recyclerView.addItemDecoration(new DividerItemDecoration(this, LinearLayoutManager.VERTICAL));
        recyclerView.setAdapter(mAdapter);

        Intent intent = getIntent();
        recherche = intent.getStringExtra("recherche");

        image_produit_full = findViewById(R.id.image_produit_full);

        mAdapter.setListeAllProduit(faireRecherche(recherche));


        mAdapter.setOnItemClickListener(new ProduitAdapterRecherche.OnItemClickListener() {
            @Override
            public void onClik(int position) {
                Intent intent = new Intent(RechercheActivity.this, FicheProduitActivity.class);
                intent.putExtra("produit", getProduit(position));
                startActivityForResult(intent, 5);

            }
            @Override
            public void onPhotoClick(int position, Drawable imageDrawable, String lien_image) {
                Picasso.with(getApplicationContext()).load(MainActivity.backOfficeURLIMG + lien_image.replace(".jpg", "_full.jpg")).into(image_produit_full);
                image_produit_full.setVisibility(View.VISIBLE);
                image_produit_full.setEnabled(true);
                image_produit_full.setAdjustViewBounds(true);
            }

        });
        recyclerView.setAdapter(mAdapter);

        //permet de refermer la photo produit
        image_produit_full.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                image_produit_full.setImageDrawable(null);
                image_produit_full.setVisibility(View.INVISIBLE);
                image_produit_full.setEnabled(false);
                image_produit_full.setAdjustViewBounds(false);
            }
        });

        searchBar.setOnQueryTextListener(new SearchView.OnQueryTextListener() {
            @Override
            public boolean onQueryTextSubmit(String s) {
                searchBar.clearFocus();
                mAdapter.setListeAllProduit(faireRecherche(s));
                mAdapter.notifyDataSetChanged();
                return false;
            }

            @Override
            public boolean onQueryTextChange(String s) {
                mAdapter.setListeAllProduit(faireRecherche(s));
                mAdapter.notifyDataSetChanged();
                return false;
            }
        });
        searchBar.clearFocus();

    }

    //Fermer la vue lors du retour en arrière
    @Override
    public void onBackPressed() {
        this.finish();
    }

    @Override
    public void onWindowFocusChanged(boolean hasFocus) {
        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }

    }

    public List<Produit> faireRecherche(String valeur) {
        resultatRecherche = new ArrayList<>();
        if (CommandesActivity.listeAllProduits != null) {
            if (!CommandesActivity.listeAllProduits.isEmpty()) {
                for (Produit p : CommandesActivity.listeAllProduits) {
                    //Recherche sur la référence, couleur, catégorie, informations (nom catégorie) et non code 128
                    if (!p.getCode128().isEmpty() && p.getCode128().toLowerCase().contains(valeur.toLowerCase())) {
                        resultatRecherche.add(p);
                    } else if (!p.getRef().isEmpty() && p.getRef().toLowerCase().contains(valeur.toLowerCase())) {
                        resultatRecherche.add(p);
                    } else if (!p.getColoris().isEmpty() && p.getColoris().toLowerCase().contains(valeur.toLowerCase())) {
                        resultatRecherche.add(p);
                    } else if (!p.getInformations().isEmpty() && p.getInformations().toLowerCase().contains(valeur.toLowerCase())) {
                        resultatRecherche.add(p);
                    } else if (!p.getNumCategorie().isEmpty() && p.getNumCategorie().toLowerCase().contains(valeur.toLowerCase())) {
                        resultatRecherche.add(p);
                    }
                }
            }
            if (resultatRecherche.size() == 0) {
                Toast.makeText(getApplicationContext(), "Aucun résultat", Toast.LENGTH_SHORT).show();
                resultatRecherche = CommandesActivity.listeAllProduits;
            }
        }

        return resultatRecherche;
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 5) {
            if (resultCode == Activity.RESULT_OK) {
                Produit p = data.getParcelableExtra("produit");
                Intent returnIntent = new Intent();
                returnIntent.putExtra("produit", p);
                setResult(Activity.RESULT_OK, returnIntent);
                finish();
            } else if (resultCode == Activity.RESULT_CANCELED) {

            }
        }
    }

    public Produit getProduit(int position) {
        return resultatRecherche.get(position);
    }

    @Override
    protected void onPause() {
        super.onPause();
    }

    @Override
    protected void onRestart() {
        super.onRestart();
    }

    @Override
    protected void onResume() {
        super.onResume();

        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
    }

    //Masquer le clavier quand on appuie en dehors du champ
    @Override
    public boolean dispatchTouchEvent(MotionEvent ev) {
        if (getCurrentFocus() != null) {
            InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
            imm.hideSoftInputFromWindow(getCurrentFocus().getWindowToken(), 0);
        }
        return super.dispatchTouchEvent(ev);
    }
}
